@@ -13,6 +13,7 @@ use swc_ecma_utils::{
 use swc_ecma_visit::{
     as_folder, noop_visit_mut_type, noop_visit_type, Fold, Visit, VisitMut, VisitMutWith, VisitWith,
 };
+use swc_trace_macro::swc_trace;
 
 pub fn spread(c: Config) -> impl Fold + VisitMut {
     as_folder(Spread {
@@ -34,6 +35,7 @@ struct Spread {
     vars: Vec<VarDeclarator>,
 }
 
+#[swc_trace]
 #[fast_path(SpreadFinder)]
 impl VisitMut for Spread {
     noop_visit_mut_type!();
@@ -184,6 +186,7 @@ impl VisitMut for Spread {
     }
 }
 
+#[swc_trace]
 impl Spread {
     fn visit_mut_stmt_like<T>(&mut self, items: &mut Vec<T>)
     where
@@ -210,6 +213,7 @@ impl Spread {
     }
 }
 
+#[swc_trace]
 impl Spread {
     fn concat_args(
         &self,
@@ -389,6 +393,7 @@ impl Spread {
     }
 }
 
+#[tracing::instrument(level = "trace", skip_all)]
 fn expand_literal_args(
     args: impl ExactSizeIterator + Iterator<Item = Option<ExprOrSpread>>,
 ) -> Vec<Option<ExprOrSpread>> {
